==> geopsypack-src-3.4.0.tar.gz: geopsypack-src-3.4.0/SciFigs/src/XYPlotProperties.h <==
/***************************************************************************
**
**  This file is part of SciFigs.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2005-07-04
**  Copyright: 2005-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef XYPLOTPROPERTIES_H
#define XYPLOTPROPERTIES_H

#include <QGpGuiTools.h>

#include "ui_XYPlotProperties.h"

namespace SciFigs {

class XYPlot;

class XYPlotProperties : public PropertyWidget, protected Ui::XYPlotProperties
{
public:
  XYPlotProperties(QWidget * parent=nullptr);

  enum Properties {DotDiameter, Symbol};
};


} // namespace SciFigs

#endif // XYPLOTPROPERTIES_H

==> geopsypack-src-3.5.1.tar.gz: geopsypack-src-3.5.1/SciFigs/src/XYPlotProperties.h <==
/***************************************************************************
**
**  This file is part of SciFigs.
**
**  This library is free software; you can redistribute it and/or
**  modify it under the terms of the GNU Lesser General Public
**  License as published by the Free Software Foundation; either
**  version 2.1 of the License, or (at your option) any later version.
**
**  This file is distributed in the hope that it will be useful, but WITHOUT
**  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
**  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
**  License for more details.
**
**  You should have received a copy of the GNU Lesser General Public
**  License along with this library; if not, write to the Free Software
**  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
**
**  See http://www.geopsy.org for more information.
**
**  Created: 2005-07-04
**  Copyright: 2005-2019
**    Marc Wathelet
**    Marc Wathelet (LGIT, Grenoble, France)
**
***************************************************************************/

#ifndef XYPLOTPROPERTIES_H
#define XYPLOTPROPERTIES_H

#include <QGpGuiTools.h>

#include "SciFigsDLLExport.h"

namespace Ui {
  class XYPlotProperties;
}

namespace SciFigs {

  class SCIFIGS_EXPORT XYPlotProperties : public PropertyWidget
  {
  public:
    XYPlotProperties(QWidget * parent=nullptr);

    void removeSymbol();

    enum Properties {DotDiameter, Symbol};
  private:
    Ui::XYPlotProperties * _ui;
  };

} // namespace SciFigs

#endif // XYPLOTPROPERTIES_H
